#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

import os

from ionas import request
from product_conf import (LIBEXEC_DIR, STOR_IF_TO_VOL, )
from product_conf.devinfo import (VOL_INFO,)
from fal_info import (FAL_VOLCTRL_PATH, Results, ReqTypes)

from pkgaddon.flets_azukeru_config import (MAN_NAME,)


INTERNAL_VOL = STOR_IF_TO_VOL["internal"][1]
MANUAL_PATH = os.path.join(VOL_INFO[INTERNAL_VOL]["mnt_point"],
                            VOL_INFO[INTERNAL_VOL]["share_root"],
                            "LAN DISK Manual", MAN_NAME,)

VOLUME_QUERY_REQ_XML_TMPL = \
    '<volctrl><volume><name type="volume">%s</name></volume></volctrl>'

VOLUME_STATUS_PATH = "volume/status"
STATUS_MOUNTED = "mounted"

MOUNT_EVENT_XML = '<events><eventinfo category="volume" action="mount">' + \
                    '<volume><name>' + INTERNAL_VOL + '</name></volume>' + \
                    '</eventinfo></events>'

HANDLER_FOR_MAN = os.path.join(LIBEXEC_DIR, "evh",
                                    "evh_flets_azukeru_manual_set.py")


def __send_request(target, type, body=""):
    """Send request entry to "target"."""

    entry = request.Entry(type, body)
    return request.Request(target).request(entry).get_entry()


def _is_volume_mounted(vol):
    """Check if "vol" is mounted."""

    result_entry = __send_request(FAL_VOLCTRL_PATH, ReqTypes.QUERY,
                            VOLUME_QUERY_REQ_XML_TMPL % (vol,))

    if (result_entry.get_result() == Results.OK and
        result_entry.get().get_value(VOLUME_STATUS_PATH) == STATUS_MOUNTED):

        return True

    return False


def install():
    """Install manual."""

    if _is_volume_mounted(INTERNAL_VOL):
        __send_request(HANDLER_FOR_MAN, ReqTypes.EVENT, MOUNT_EVENT_XML)


def update():
    """Update manual."""

    install()


def uninstall():
    """uninstall manual."""

    if os.path.exists(MANUAL_PATH):
        os.unlink(MANUAL_PATH)
