# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import division

import os

from django.utils.translation import ugettext as _
from django import forms

from project.view import FuncView as _View


class NameField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '接続名')
        super(NameField, self).__init__(*args, **kwargs)


class ContractorField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '契約会社')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.Select)
        kwargs['choices'] = kwargs.get('choices', [
            ('east', 'NTT東日本'),
            ('west', 'NTT西日本'),
            ('other', 'その他'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][0][0])
        super(ContractorField, self).__init__(*args, **kwargs)


class PlanField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '契約プラン')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.Select)
        kwargs['choices'] = kwargs.get('choices', [
            ('azukeru', 'あずけ～る有料/無料プラン'),
            ('azukeru_pro', 'あずけ～るPROプラン'),
            ('azukeru_aio', 'まるらくオフィス'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][0][0])
        super(PlanField, self).__init__(*args, **kwargs)


class AuthMethodField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '認証方式')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.Select)
        kwargs['choices'] = kwargs.get('choices', [
            ('east_line_auth', '回線認証(東日本)'),
            ('west_line_auth', '回線認証(西日本)'),
            ('terminal_auth', '端末認証'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][0][0])
        super(AuthMethodField, self).__init__(*args, **kwargs)


class OtherAuthMethodField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '認証方式')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.Select)
        kwargs['choices'] = kwargs.get('choices', [
            ('line_auth', '回線認証'),
            ('terminal_auth', '端末認証'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][0][0])
        super(OtherAuthMethodField, self).__init__(*args, **kwargs)


class TerminalKeyField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '端末認証キー')
        kwargs['required'] = kwargs.get('required', False)
        super(TerminalKeyField, self).__init__(*args, **kwargs)


class ClientIdField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'クライアントID')
        super(ClientIdField, self).__init__(*args, **kwargs)


class PasswordField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'パスワード')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.PasswordInput(render_value=True))
        super(PasswordField, self).__init__(*args, **kwargs)
